@@ -208,7 +208,11 @@ class PropertiesModel(updates.UpdateInterface):
         # Create reference
         clip_data = c.data
         if object_id:
-            clip_data = c.data.get('objects').get(object_id)
+            objects = c.data.get('objects', {})
+            clip_data = objects.pop(object_id, {})
+            if not clip_data:
+                log.debug("No clip data found for this object id")
+                return
 
         if property_key in clip_data:  # Update clip attribute
             log_id = "{}/{}".format(clip_id, object_id) if object_id else clip_id
@@ -222,8 +226,7 @@ class PropertiesModel(updates.UpdateInterface):
                 keyframe_list = [clip_data[property_key]]
 
             # Loop through each keyframe (red, blue, and green)
-            for keyframe in keyframe_list:
-
+            for keyframe_index, keyframe in enumerate(keyframe_list):
                 # Keyframe
                 # Loop through points, find a matching points on this frame
                 closest_point = None
@@ -247,6 +250,32 @@ class PropertiesModel(updates.UpdateInterface):
                     log.debug("Found point to delete at X=%s" % point_to_delete["co"]["X"])
                     keyframe["Points"].remove(point_to_delete)
 
+                    # Check for 0 keyframes (and use sane defaults instead of the 0.0 default value)
+                    default_value = None
+                    if not keyframe["Points"]:
+                        if property_key in ["alpha", "scale_x", "scale_y", "time", "volume"]:
+                            default_value = 1.0
+                        elif property_key in ["origin_x", "origin_y"]:
+                            default_value = 0.5
+                        elif property_key in ["location_x", "location_y", "rotation", "shear_x", "shear_y"]:
+                            default_value = 0.0
+                        elif property_key in ["has_audio", "has_video", "channel_filter", "channel_mapping"]:
+                            default_value = -1.0
+                        elif property_key in ["wave_color"]:
+                            if keyframe_index == 0:
+                                # Red
+                                default_value = 0.0
+                            elif keyframe_index == 1:
+                                # Blue
+                                default_value = 255.0
+                            elif keyframe_index == 2:
+                                # Green
+                                default_value = 123.0
+                        if default_value is not None:
+                            keyframe["Points"].append({
+                                'co': {'X': self.frame_number, 'Y': default_value},
+                                'interpolation': 1})
+
             # Determine if waveforms are impacted by this change
             has_waveform = False
             waveform_file_id = None
@@ -256,13 +285,17 @@ class PropertiesModel(updates.UpdateInterface):
                     has_waveform = True
 
             # Reduce # of clip properties we are saving (performance boost)
-            clip_data = {property_key: clip_data[property_key]}
-            if object_id:
-                clip_data = {'objects': {object_id: clip_data}}
+            if not object_id:
+                clip_data = {property_key: clip_data.get(property_key)}
+            else:
+                # If objects dict detected - don't reduce the # of objects
+                objects[object_id] = clip_data
+                clip_data = {'objects': objects}
 
             # Save changes
             if clip_updated:
                 # Save
+                c.data = clip_data
                 c.save()
 
                 # Update waveforms (if needed)
@@ -306,7 +339,11 @@ class PropertiesModel(updates.UpdateInterface):
                 # Create reference
                 clip_data = c.data
                 if object_id:
-                    clip_data = c.data.get('objects').get(object_id)
+                    objects = c.data.get('objects', {})
+                    clip_data = objects.pop(object_id, {})
+                    if not clip_data:
+                        log.debug("No clip data found for this object id")
+                        return
 
                 # Update clip attribute
                 if property_key in clip_data:
@@ -378,13 +415,17 @@ class PropertiesModel(updates.UpdateInterface):
                                 })
 
                 # Reduce # of clip properties we are saving (performance boost)
-                clip_data = {property_key: clip_data[property_key]}
-                if object_id:
-                    clip_data = {'objects': {object_id: clip_data}}
+                if not object_id:
+                    clip_data = {property_key: clip_data.get(property_key)}
+                else:
+                    # If objects dict detected - don't reduce the # of objects
+                    objects[object_id] = clip_data
+                    clip_data = {'objects': objects}
 
                 # Save changes
                 if clip_updated:
                     # Save
+                    c.data = clip_data
                     c.save()
 
                     # Update the preview
@@ -409,12 +450,15 @@ class PropertiesModel(updates.UpdateInterface):
         property_type = property[1]["type"]
         property_key = property[0]
         object_id = property[1]["object_id"]
+        objects = {}
         clip_id, item_type = item.data()
 
         # Get value (if any)
-        if item.text():
+        if item.text() or value:
             # Set and format value based on property type
-            if value is not None:
+            if value == "None":
+                new_value = ""
+            elif value is not None:
                 # Override value
                 new_value = value
             elif property_type == "string":
@@ -453,12 +497,16 @@ class PropertiesModel(updates.UpdateInterface):
             # Get effect object
             c = Effect.get(id=clip_id)
 
-        if c:
+        if c and c.data:
 
             # Create reference
             clip_data = c.data
             if object_id:
-                clip_data = c.data.get('objects').get(object_id)
+                objects = c.data.get('objects', {})
+                clip_data = objects.pop(object_id, {})
+                if not clip_data:
+                    log.debug("No clip data found for this object id")
+                    return
 
             # Update clip attribute
             if property_key in clip_data:
@@ -468,6 +516,23 @@ class PropertiesModel(updates.UpdateInterface):
                 # Check the type of property (some are keyframe, and some are not)
                 if property_type != "reader" and isinstance(clip_data[property_key], dict):
                     # Keyframe
+
+                    # Protection from HUGE scale values
+                    if property_key in ['scale_x', 'scale_y', 'shear_x', 'shear_y']:
+                        width = get_app().project.get("width")
+                        height = get_app().project.get("height")
+                        is_svg = clip_data.get("reader", {}).get("path", "").lower().endswith("svg")
+                        if is_svg:
+                            max_multiple = 15
+                        else:
+                            max_multiple = 50
+                        if width > 0 and height > 0:
+                            # Clamp the max scale based on project size
+                            max_multiple = round((2000 * max_multiple) / max(width, height))
+
+                        # Apply the calculated max_multiple to new_value
+                        new_value = max(min(new_value, max_multiple), -max_multiple)
+
                     # Loop through points, find a matching points on this frame
                     found_point = False
                     point_to_delete = None
@@ -559,7 +624,7 @@ class PropertiesModel(updates.UpdateInterface):
                 elif property_type == "string":
                     clip_updated = True
                     try:
-                        clip_data[property_key] = str(new_value)
+                        clip_data[property_key] = str(new_value or "")
                     except Exception:
                         log.warn('Invalid String value passed to property', exc_info=1)
 
@@ -591,9 +656,12 @@ class PropertiesModel(updates.UpdateInterface):
                     has_waveform = True
 
             # Reduce # of clip properties we are saving (performance boost)
-            clip_data = {property_key: clip_data.get(property_key)}
-            if object_id:
-                clip_data = {'objects': {object_id: clip_data}}
+            if not object_id:
+                clip_data = {property_key: clip_data.get(property_key)}
+            else:
+                # If objects dict detected - don't reduce the # of objects
+                objects[object_id] = clip_data
+                clip_data = {'objects': objects}
 
             # Save changes
             if clip_updated:
@@ -741,7 +809,7 @@ class PropertiesModel(updates.UpdateInterface):
             # Append ROW to MODEL (if does not already exist in model)
             self.model.appendRow(row)
 
-        else:
+        elif name in self.items and self.items[name]["row"]:
             # Update the value of the existing model
             # Get 1st Column
             col = self.items[name]["row"][0]
@@ -851,8 +919,17 @@ class PropertiesModel(updates.UpdateInterface):
 
             # Get raw unordered JSON properties
             raw_properties = json.loads(c.PropertiesJSON(self.frame_number))
-            objects_raw_properties = raw_properties.pop('objects', None)
 
+            # If a tracked object is found in this list, insert those properties as well
+            tracked_object_id = None
+            tracked_object_properties = {}
+            tracked_objects_raw_properties = raw_properties.pop('objects', None)
+            if tracked_objects_raw_properties:
+                tracked_object_id = list(tracked_objects_raw_properties.keys())[0]
+                tracked_object_properties = tracked_objects_raw_properties[tracked_object_id]
+                raw_properties.update(tracked_object_properties)
+
+            # Sort all properties (by 'name')
             all_properties = OrderedDict(sorted(raw_properties.items(), key=lambda x: x[1]['name']))
 
             # Check if filter was changed (if so, wipe previous model data)
@@ -877,14 +954,12 @@ class PropertiesModel(updates.UpdateInterface):
 
             # Loop through properties, and build a model
             for property in all_properties.items():
-                self.set_property(property, filter, c, item_type)
-
-            # Insert objects properties from custom effects
-            if objects_raw_properties:
-                for obj_id in objects_raw_properties:
-                    objects_all_properties = OrderedDict(sorted(objects_raw_properties[obj_id].items(), key=lambda x: x[1]['name']))
-                    for property in objects_all_properties.items():
-                        self.set_property(property, filter, c, item_type, object_id=obj_id)
+                if property[0] in tracked_object_properties:
+                    # Add tracked object property
+                    self.set_property(property, filter, c, item_type, object_id=tracked_object_id)
+                else:
+                    # Add base property
+                    self.set_property(property, filter, c, item_type)
 
             # Update the values on the next call to this method (instead of adding rows)
             self.new_item = False
