@@ -29,7 +29,7 @@ from PyQt5.QtCore import (
     Qt, QCoreApplication, QRectF, QTimer
 )
 from PyQt5.QtGui import (
-    QPainter, QPixmap, QColor, QPen, QBrush, QCursor, QPainterPath
+    QPainter, QColor, QPen, QBrush, QCursor, QPainterPath, QIcon
 )
 from PyQt5.QtWidgets import QSizePolicy, QWidget
 
@@ -38,6 +38,7 @@ import openshot  # Python module for libopenshot (required video editing module
 from classes import updates
 from classes.app import get_app
 from classes.query import Clip, Track, Transition, Marker
+from themes.manager import ThemeManager
 
 
 class ZoomSlider(QWidget, updates.UpdateInterface):
@@ -56,7 +57,8 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
             layers[layer.data.get('number')] = count
 
         # Wait for timeline object and valid scrollbar positions
-        if hasattr(get_app().window, "timeline") and self.scrollbar_position[2] != 0.0:
+        # TODO: Fix commented out logic
+        if hasattr(get_app().window, "timeline"):  # and self.scrollbar_position[2] != 0.0:
             # Get max width of timeline
             project_duration = get_app().project.get("duration")
             pixels_per_second = self.width() / project_duration
@@ -105,12 +107,19 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         """ Custom paint event """
         event.accept()
 
+        # Get theme colors
+        theme = ThemeManager().get_current_theme()
+        if not theme:
+            return
+        playhead_color = theme.get_color(".zoom_slider_playhead", "background-color")
+
         # Paint timeline preview on QWidget
         painter = QPainter(self)
         painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform | QPainter.TextAntialiasing, True)
 
         # Fill the whole widget with the solid color (background solid color)
-        painter.fillRect(event.rect(), QColor("#191919"))
+        background_color = self.palette().color(self.palette().Base)
+        painter.fillRect(event.rect(), background_color)
 
         # Create pens / colors
         clip_pen = QPen(QBrush(QColor("#53a0ed")), 1.5)
@@ -128,8 +137,7 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         marker_pen = QPen(QBrush(marker_color), 1.0)
         marker_pen.setCosmetic(True)
 
-        playhead_color = QColor(Qt.red)
-        playhead_color.setAlphaF(0.5)
+        playhead_color = playhead_color
         playhead_pen = QPen(QBrush(playhead_color), 1.0)
         playhead_pen.setCosmetic(True)
 
@@ -141,7 +149,8 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         layers = Track.filter()
 
         # Wait for timeline object and valid scrollbar positions
-        if get_app().window.timeline and self.scrollbar_position[2] != 0.0:
+        # TODO: Fix commented out logic
+        if get_app().window.timeline:  # and self.scrollbar_position[2] != 0.0:
             # Get max width of timeline
             project_duration = get_app().project.get("duration")
             pixels_per_second = event.rect().width() / project_duration
@@ -150,7 +159,7 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
 
             # Get FPS info
             fps_num = get_app().project.get("fps").get("num", 24)
-            fps_den = get_app().project.get("fps").get("den", 1)
+            fps_den = get_app().project.get("fps").get("den", 1) or 1
             fps_float = float(fps_num / fps_den)
 
             # Determine scale factor
@@ -222,9 +231,6 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         self.mouse_position = event.pos().x()
         self.scrollbar_position_previous = self.scrollbar_position
 
-        # Ignore undo/redo history temporarily (to avoid a huge pile of undo/redo history)
-        get_app().updates.ignore_history = True
-
     def mouseReleaseEvent(self, event):
         """Capture mouse release event"""
         event.accept()
@@ -502,12 +508,11 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         self.is_auto_center = True
         self.min_distance = 0.02
 
-        # Initialize cursors
-        self.cursors = {
-            "move": QCursor(QPixmap(":/cursors/cursor_move.png")),
-            "resize_x": QCursor(QPixmap(":/cursors/cursor_resize_x.png")),
-            "hand": QCursor(QPixmap(":/cursors/cursor_hand.png")),
-            }
+        # Load icon (using display DPI)
+        self.cursors = {}
+        for cursor_name in ["move", "resize_x", "hand"]:
+            icon = QIcon(":/cursors/cursor_%s.png" % cursor_name)
+            self.cursors[cursor_name] = QCursor(icon.pixmap(24, 24))
 
         # Init Qt widget's properties (background repainting, etc...)
         super().setAttribute(Qt.WA_OpaquePaintEvent)
@@ -525,6 +530,8 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         # Connect zoom functionality
         self.win.TimelineScrolled.connect(self.update_scrollbars)
 
+        self.win.TimelineResize.connect(self.delayed_resize_callback)
+
         # Connect Selection signals
         self.win.SelectionChanged.connect(self.handle_selection)
 
@@ -532,6 +539,6 @@ class ZoomSlider(QWidget, updates.UpdateInterface):
         # Timer to use a delay before sending MaxSizeChanged signals (so we don't spam libopenshot)
         self.delayed_size = None
         self.delayed_resize_timer = QTimer(self)
-        self.delayed_resize_timer.setInterval(200)
+        self.delayed_resize_timer.setInterval(100)
         self.delayed_resize_timer.setSingleShot(True)
         self.delayed_resize_timer.timeout.connect(self.delayed_resize_callback)
